{"00000:1": "

    {% from 'macros/nav.jinja' import menu with context %}\n<!DOCTYPE HTML>\n<!--\nAltitude: A responsive HTML5 website template by HTML5Templates.com\nReleased for free under the Creative Commons Attribution 3.0 license (html5templates.com/license)\nVisit http://html5templates.com for more great templates or follow us on Twitter @HTML5T\n-->\n<html>\n    {% block head -%}\n    {% include 'macros/_header.html' -%}\n    {% endblock -%}\n    <body>\n        <div id="wrapper">\n            <div id="header-wrapper">\n                <header id="header">\n                <div class="5grid-layout">\n                    <div id="menu">\n                        <nav class="mobileUI-site-nav">\n                        {% block nav_menu -%}\n                        {{ menu() }}\n                        {% endblock -%}\n                        </nav>\n                    </div>\n                </div>\n                {% block logo -%}\n                {% include 'macros/_logo.html' -%}\n                {% endblock -%}\n                </header>\n            </div>\n            {% block banner -%}\n            {% include 'macros/_banner.html' -%}\n            <div class="divider"></div>\n            {% endblock -%}\n            {% block mainpage -%}\n            <div id="page-wrapper">\n                {{ content }}\n            </div>\n            {% endblock -%}\n        </div>\n        {% block footer -%}\n        {% include 'macros/_footer.html' -%}\n        {% endblock -%}\n    </div>\n</body>\n</html>\n

\n"}